@@ -6,7 +6,7 @@ import (
 	"github.com/cloudflare/pint/internal/diags"
 	"github.com/cloudflare/pint/internal/discovery"
 	"github.com/cloudflare/pint/internal/parser"
-	"github.com/cloudflare/pint/internal/parser/utils"
+	"github.com/cloudflare/pint/internal/parser/source"
 )
 
 const (
@@ -40,14 +40,14 @@ func (c ImpossibleCheck) Reporter() string {
 	return ImpossibleCheckName
 }
 
-func (c ImpossibleCheck) Check(_ context.Context, entry discovery.Entry, _ []discovery.Entry) (problems []Problem) {
+func (c ImpossibleCheck) Check(_ context.Context, entry *discovery.Entry, _ []*discovery.Entry) (problems []Problem) {
 	expr := entry.Rule.Expr()
-	if expr.SyntaxError != nil {
+	if expr.SyntaxError() != nil {
 		return problems
 	}
 
-	for _, src := range utils.LabelsSource(expr.Value.Value, expr.Query.Expr) {
-		src.WalkSources(func(s utils.Source, _ *utils.Join, _ *utils.Unless) {
+	for _, src := range expr.Source() {
+		src.WalkSources(func(s source.Source, _ *source.Join, _ *source.Unless) {
 			problems = append(problems, c.checkSource(expr, s)...)
 		})
 	}
@@ -55,7 +55,7 @@ func (c ImpossibleCheck) Check(_ context.Context, entry discovery.Entry, _ []dis
 	return problems
 }
 
-func (c ImpossibleCheck) checkSource(expr parser.PromQLExpr, s utils.Source) (problems []Problem) {
+func (c ImpossibleCheck) checkSource(expr *parser.PromQLExpr, s source.Source) (problems []Problem) {
 	if s.DeadInfo != nil {
 		problems = append(problems, Problem{
 			Anchor:   AnchorAfter,
