@@ -2,7 +2,6 @@ package promapi
 
 import (
 	"errors"
-	"fmt"
 	"net"
 
 	"github.com/prometheus/client_golang/prometheus"
@@ -12,21 +11,21 @@ var (
 	prometheusQueriesRunning = prometheus.NewGaugeVec(
 		prometheus.GaugeOpts{
 			Name: "pint_prometheus_queries_running",
-			Help: "Total number of in-flight prometheus queries",
+			Help: "Total number of in-flight prometheus queries.",
 		},
 		[]string{"name", "endpoint"},
 	)
 	prometheusQueriesTotal = prometheus.NewCounterVec(
 		prometheus.CounterOpts{
 			Name: "pint_prometheus_queries_total",
-			Help: "Total number of all prometheus queries",
+			Help: "Total number of all prometheus queries.",
 		},
 		[]string{"name", "endpoint"},
 	)
 	prometheusQueryErrorsTotal = prometheus.NewCounterVec(
 		prometheus.CounterOpts{
 			Name: "pint_prometheus_query_errors_total",
-			Help: "Total number of failed prometheus queries",
+			Help: "Total number of failed prometheus queries.",
 		},
 		[]string{"name", "endpoint", "reason"},
 	)
@@ -46,7 +45,7 @@ func errReason(err error) string {
 
 	var e1 APIError
 	if ok := errors.As(err, &e1); ok {
-		return fmt.Sprintf("api/%s", e1.ErrorType)
+		return "api/" + string(e1.ErrorType)
 	}
 
 	return "connection/error"
