@@ -50,16 +50,16 @@ const (
 type (
 	PipelinesServiceInterface interface {
 		ListProjectPipelines(pid any, opt *ListProjectPipelinesOptions, options ...RequestOptionFunc) ([]*PipelineInfo, *Response, error)
-		GetPipeline(pid any, pipeline int, options ...RequestOptionFunc) (*Pipeline, *Response, error)
-		GetPipelineVariables(pid any, pipeline int, options ...RequestOptionFunc) ([]*PipelineVariable, *Response, error)
-		GetPipelineTestReport(pid any, pipeline int, options ...RequestOptionFunc) (*PipelineTestReport, *Response, error)
-		GetPipelineTestReportSummary(pid any, pipeline int, options ...RequestOptionFunc) (*PipelineTestReportSummary, *Response, error)
+		GetPipeline(pid any, pipeline int64, options ...RequestOptionFunc) (*Pipeline, *Response, error)
+		GetPipelineVariables(pid any, pipeline int64, options ...RequestOptionFunc) ([]*PipelineVariable, *Response, error)
+		GetPipelineTestReport(pid any, pipeline int64, options ...RequestOptionFunc) (*PipelineTestReport, *Response, error)
+		GetPipelineTestReportSummary(pid any, pipeline int64, options ...RequestOptionFunc) (*PipelineTestReportSummary, *Response, error)
 		GetLatestPipeline(pid any, opt *GetLatestPipelineOptions, options ...RequestOptionFunc) (*Pipeline, *Response, error)
 		CreatePipeline(pid any, opt *CreatePipelineOptions, options ...RequestOptionFunc) (*Pipeline, *Response, error)
-		RetryPipelineBuild(pid any, pipeline int, options ...RequestOptionFunc) (*Pipeline, *Response, error)
-		CancelPipelineBuild(pid any, pipeline int, options ...RequestOptionFunc) (*Pipeline, *Response, error)
-		DeletePipeline(pid any, pipeline int, options ...RequestOptionFunc) (*Response, error)
-		UpdatePipelineMetadata(pid any, pipeline int, opt *UpdatePipelineMetadataOptions, options ...RequestOptionFunc) (*Pipeline, *Response, error)
+		RetryPipelineBuild(pid any, pipeline int64, options ...RequestOptionFunc) (*Pipeline, *Response, error)
+		CancelPipelineBuild(pid any, pipeline int64, options ...RequestOptionFunc) (*Pipeline, *Response, error)
+		DeletePipeline(pid any, pipeline int64, options ...RequestOptionFunc) (*Response, error)
+		UpdatePipelineMetadata(pid any, pipeline int64, opt *UpdatePipelineMetadataOptions, options ...RequestOptionFunc) (*Pipeline, *Response, error)
 	}
 
 	// PipelinesService handles communication with the repositories related
@@ -86,7 +86,7 @@ type PipelineVariable struct {
 //
 // GitLab API docs: https://docs.gitlab.com/api/pipelines/
 type PipelineInput struct {
-	Name  string `json:"key"`
+	Name  string `json:"name"`
 	Value any    `json:"value"`
 }
 
@@ -94,9 +94,9 @@ type PipelineInput struct {
 //
 // GitLab API docs: https://docs.gitlab.com/api/pipelines/
 type Pipeline struct {
-	ID             int             `json:"id"`
-	IID            int             `json:"iid"`
-	ProjectID      int             `json:"project_id"`
+	ID             int64           `json:"id"`
+	IID            int64           `json:"iid"`
+	ProjectID      int64           `json:"project_id"`
 	Status         string          `json:"status"`
 	Source         PipelineSource  `json:"source"`
 	Ref            string          `json:"ref"`
@@ -111,40 +111,51 @@ type Pipeline struct {
 	StartedAt      *time.Time      `json:"started_at"`
 	FinishedAt     *time.Time      `json:"finished_at"`
 	CommittedAt    *time.Time      `json:"committed_at"`
-	Duration       int             `json:"duration"`
-	QueuedDuration int             `json:"queued_duration"`
+	Duration       int64           `json:"duration"`
+	QueuedDuration int64           `json:"queued_duration"`
 	Coverage       string          `json:"coverage"`
 	WebURL         string          `json:"web_url"`
 	DetailedStatus *DetailedStatus `json:"detailed_status"`
 }
 
-// DetailedStatus contains detailed information about the status of a pipeline.
-type DetailedStatus struct {
-	Icon         string `json:"icon"`
-	Text         string `json:"text"`
-	Label        string `json:"label"`
-	Group        string `json:"group"`
-	Tooltip      string `json:"tooltip"`
-	HasDetails   bool   `json:"has_details"`
-	DetailsPath  string `json:"details_path"`
-	Illustration struct {
-		Image string `json:"image"`
-	} `json:"illustration"`
-	Favicon string `json:"favicon"`
-}
-
 func (p Pipeline) String() string {
 	return Stringify(p)
 }
 
+// DetailedStatus contains detailed information about the status of a pipeline.
+type DetailedStatus struct {
+	Icon         string                     `json:"icon"`
+	Text         string                     `json:"text"`
+	Label        string                     `json:"label"`
+	Group        string                     `json:"group"`
+	Tooltip      string                     `json:"tooltip"`
+	HasDetails   bool                       `json:"has_details"`
+	DetailsPath  string                     `json:"details_path"`
+	Illustration DetailedStatusIllustration `json:"illustration"`
+	Favicon      string                     `json:"favicon"`
+}
+
+func (s DetailedStatus) String() string {
+	return Stringify(s)
+}
+
+// DetailedStatusIllustration contains detailed information about the status illustration of a pipeline.
+type DetailedStatusIllustration struct {
+	Image string `json:"image"`
+}
+
+func (i DetailedStatusIllustration) String() string {
+	return Stringify(i)
+}
+
 // PipelineTestReport contains a detailed report of a test run.
 type PipelineTestReport struct {
 	TotalTime    float64               `json:"total_time"`
-	TotalCount   int                   `json:"total_count"`
-	SuccessCount int                   `json:"success_count"`
-	FailedCount  int                   `json:"failed_count"`
-	SkippedCount int                   `json:"skipped_count"`
-	ErrorCount   int                   `json:"error_count"`
+	TotalCount   int64                 `json:"total_count"`
+	SuccessCount int64                 `json:"success_count"`
+	FailedCount  int64                 `json:"failed_count"`
+	SkippedCount int64                 `json:"skipped_count"`
+	ErrorCount   int64                 `json:"error_count"`
 	TestSuites   []*PipelineTestSuites `json:"test_suites"`
 }
 
@@ -152,11 +163,11 @@ type PipelineTestReport struct {
 type PipelineTestSuites struct {
 	Name         string               `json:"name"`
 	TotalTime    float64              `json:"total_time"`
-	TotalCount   int                  `json:"total_count"`
-	SuccessCount int                  `json:"success_count"`
-	FailedCount  int                  `json:"failed_count"`
-	SkippedCount int                  `json:"skipped_count"`
-	ErrorCount   int                  `json:"error_count"`
+	TotalCount   int64                `json:"total_count"`
+	SuccessCount int64                `json:"success_count"`
+	FailedCount  int64                `json:"failed_count"`
+	SkippedCount int64                `json:"skipped_count"`
+	ErrorCount   int64                `json:"error_count"`
 	TestCases    []*PipelineTestCases `json:"test_cases"`
 }
 
@@ -183,11 +194,11 @@ type PipelineTestReportSummary struct {
 type PipelineTotalSummary struct {
 	// Documentation examples only show whole numbers, but the test specs for GitLab show decimals, so `float64` is the better attribute here.
 	Time       float64 `json:"time"`
-	Count      int     `json:"count"`
-	Success    int     `json:"success"`
-	Failed     int     `json:"failed"`
-	Skipped    int     `json:"skipped"`
-	Error      int     `json:"error"`
+	Count      int64   `json:"count"`
+	Success    int64   `json:"success"`
+	Failed     int64   `json:"failed"`
+	Skipped    int64   `json:"skipped"`
+	Error      int64   `json:"error"`
 	SuiteError *string `json:"suite_error"`
 }
 
@@ -195,18 +206,18 @@ type PipelineTotalSummary struct {
 type PipelineTestSuiteSummary struct {
 	Name         string  `json:"name"`
 	TotalTime    float64 `json:"total_time"`
-	TotalCount   int     `json:"total_count"`
-	SuccessCount int     `json:"success_count"`
-	FailedCount  int     `json:"failed_count"`
-	SkippedCount int     `json:"skipped_count"`
-	ErrorCount   int     `json:"error_count"`
-	BuildIDs     []int   `json:"build_ids"`
+	TotalCount   int64   `json:"total_count"`
+	SuccessCount int64   `json:"success_count"`
+	FailedCount  int64   `json:"failed_count"`
+	SkippedCount int64   `json:"skipped_count"`
+	ErrorCount   int64   `json:"error_count"`
+	BuildIDs     []int64 `json:"build_ids"`
 	SuiteError   *string `json:"suite_error"`
 }
 
 // RecentFailures contains failures count for the project's default branch.
 type RecentFailures struct {
-	Count      int    `json:"count"`
+	Count      int64  `json:"count"`
 	BaseBranch string `json:"base_branch"`
 }
 
@@ -217,9 +228,9 @@ func (p PipelineTestReport) String() string {
 // PipelineInfo shows the basic entities of a pipeline, mostly used as fields
 // on other assets, like Commit.
 type PipelineInfo struct {
-	ID        int        `json:"id"`
-	IID       int        `json:"iid"`
-	ProjectID int        `json:"project_id"`
+	ID        int64      `json:"id"`
+	IID       int64      `json:"iid"`
+	ProjectID int64      `json:"project_id"`
 	Status    string     `json:"status"`
 	Source    string     `json:"source"`
 	Ref       string     `json:"ref"`
@@ -286,7 +297,7 @@ func (s *PipelinesService) ListProjectPipelines(pid any, opt *ListProjectPipelin
 //
 // GitLab API docs:
 // https://docs.gitlab.com/api/pipelines/#get-a-single-pipeline
-func (s *PipelinesService) GetPipeline(pid any, pipeline int, options ...RequestOptionFunc) (*Pipeline, *Response, error) {
+func (s *PipelinesService) GetPipeline(pid any, pipeline int64, options ...RequestOptionFunc) (*Pipeline, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
 		return nil, nil, err
@@ -311,7 +322,7 @@ func (s *PipelinesService) GetPipeline(pid any, pipeline int, options ...Request
 //
 // GitLab API docs:
 // https://docs.gitlab.com/api/pipelines/#get-variables-of-a-pipeline
-func (s *PipelinesService) GetPipelineVariables(pid any, pipeline int, options ...RequestOptionFunc) ([]*PipelineVariable, *Response, error) {
+func (s *PipelinesService) GetPipelineVariables(pid any, pipeline int64, options ...RequestOptionFunc) ([]*PipelineVariable, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
 		return nil, nil, err
@@ -336,7 +347,7 @@ func (s *PipelinesService) GetPipelineVariables(pid any, pipeline int, options .
 //
 // GitLab API docs:
 // https://docs.gitlab.com/api/pipelines/#get-a-pipelines-test-report
-func (s *PipelinesService) GetPipelineTestReport(pid any, pipeline int, options ...RequestOptionFunc) (*PipelineTestReport, *Response, error) {
+func (s *PipelinesService) GetPipelineTestReport(pid any, pipeline int64, options ...RequestOptionFunc) (*PipelineTestReport, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
 		return nil, nil, err
@@ -361,7 +372,7 @@ func (s *PipelinesService) GetPipelineTestReport(pid any, pipeline int, options
 //
 // GitLab API docs:
 // https://docs.gitlab.com/api/pipelines/#get-a-test-report-summary-for-a-pipeline
-func (s *PipelinesService) GetPipelineTestReportSummary(pid any, pipeline int, options ...RequestOptionFunc) (*PipelineTestReportSummary, *Response, error) {
+func (s *PipelinesService) GetPipelineTestReportSummary(pid any, pipeline int64, options ...RequestOptionFunc) (*PipelineTestReportSummary, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
 		return nil, nil, err
@@ -527,7 +538,7 @@ func (s *PipelinesService) CreatePipeline(pid any, opt *CreatePipelineOptions, o
 //
 // GitLab API docs:
 // https://docs.gitlab.com/api/pipelines/#retry-jobs-in-a-pipeline
-func (s *PipelinesService) RetryPipelineBuild(pid any, pipeline int, options ...RequestOptionFunc) (*Pipeline, *Response, error) {
+func (s *PipelinesService) RetryPipelineBuild(pid any, pipeline int64, options ...RequestOptionFunc) (*Pipeline, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
 		return nil, nil, err
@@ -552,7 +563,7 @@ func (s *PipelinesService) RetryPipelineBuild(pid any, pipeline int, options ...
 //
 // GitLab API docs:
 // https://docs.gitlab.com/api/pipelines/#cancel-a-pipelines-jobs
-func (s *PipelinesService) CancelPipelineBuild(pid any, pipeline int, options ...RequestOptionFunc) (*Pipeline, *Response, error) {
+func (s *PipelinesService) CancelPipelineBuild(pid any, pipeline int64, options ...RequestOptionFunc) (*Pipeline, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
 		return nil, nil, err
@@ -577,7 +588,7 @@ func (s *PipelinesService) CancelPipelineBuild(pid any, pipeline int, options ..
 //
 // GitLab API docs:
 // https://docs.gitlab.com/api/pipelines/#delete-a-pipeline
-func (s *PipelinesService) DeletePipeline(pid any, pipeline int, options ...RequestOptionFunc) (*Response, error) {
+func (s *PipelinesService) DeletePipeline(pid any, pipeline int64, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
 		return nil, err
@@ -606,7 +617,7 @@ type UpdatePipelineMetadataOptions struct {
 //
 // GitLab API docs:
 // https://docs.gitlab.com/api/pipelines/#update-pipeline-metadata
-func (s *PipelinesService) UpdatePipelineMetadata(pid any, pipeline int, opt *UpdatePipelineMetadataOptions, options ...RequestOptionFunc) (*Pipeline, *Response, error) {
+func (s *PipelinesService) UpdatePipelineMetadata(pid any, pipeline int64, opt *UpdatePipelineMetadataOptions, options ...RequestOptionFunc) (*Pipeline, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
 		return nil, nil, err
